@@ -3,9 +3,11 @@ Main interface for datapipeline service type definitions.
 
 Usage::
 
-    from mypy_boto3.datapipeline.type_defs import FieldTypeDef
+    ```python
+    from mypy_boto3_datapipeline.type_defs import FieldTypeDef
 
     data: FieldTypeDef = {...}
+    ```
 """
 import sys
 from typing import Dict, List
